"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.calcWidth = exports.calcPositionFromTime = exports.createTimeTicks = void 0;

var _luxon = require("luxon");

var _timeProvider = require("../time-provider");

var trackStepInMin = 5;
var pxPerMinute = 50 / trackStepInMin;

var createTimeTicks = function createTimeTicks(startEvent, endEvent) {
  var ticks = (0, _timeProvider.createTimeRange)(startEvent, endEvent, trackStepInMin);
  return ticks;
};

exports.createTimeTicks = createTimeTicks;

var calcPositionFromTime = function calcPositionFromTime(startEvent) {
  var k = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  var secStart = (0, _timeProvider.iso2sec)(startEvent);
  return function (event) {
    var time = event.time,
        isoDate = event.isoDate,
        z = event.z;
    var local = (0, _timeProvider.convertEventTimeToLocal)(isoDate, time, z);
    var sec = local.sec;
    var dist = (sec - secStart) * pxPerMinute * k / 60;
    return dist;
  };
};

exports.calcPositionFromTime = calcPositionFromTime;

var calcWidth = function calcWidth(duration) {
  var k = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  var mm = parseInt(duration, 10);
  var width = mm * pxPerMinute * k;
  return width;
};

exports.calcWidth = calcWidth;